# Grid

The **grid** submodule generates a ACV point cloud using Python-only functions. While naturally slower than the C++ version implemented in LabelLib it allows for rapid prototyping.

```{eval-rst}
.. automodule:: fretraj.grid
   :members:
   :undoc-members:
```
